@@ -72,7 +72,7 @@ sub generate_script {
 
     unlink $file if -e $file;
 
-    my $body = "use blib;\n";
+    my $body = "BEGIN { eval { require blib; } }\n";
 
     $body .= Apache::TestConfig->modperl_2_inc_fixup;
 
