@@ -461,7 +461,7 @@ sub generate_script {
     $file ||= catfile 't', 'SMOKE';
 
     my $content = join "\n",
-        "use blib;",
+        "BEGIN { eval { require blib; } }",
         Apache::TestConfig->modperl_2_inc_fixup,
         Apache::TestConfig->perlscript_header,
         "use $class;",
